@@ -6,16 +6,16 @@ import uuid
 
 from py4j.java_gateway import CallbackServerParameters
 
-from pyspark import SparkContext
-
 import mlflow
+from mlflow import MlflowClient
 from mlflow.exceptions import MlflowException
-from mlflow.tracking.client import MlflowClient
 from mlflow.tracking.context.abstract_context import RunContextProvider
+from mlflow.utils import _truncate_and_ellipsize
 from mlflow.utils.autologging_utils import (
     autologging_is_disabled,
     ExceptionSafeClass,
 )
+from mlflow.utils.validation import MAX_TAG_VAL_LENGTH
 from mlflow.utils.databricks_utils import get_repl_id as get_databricks_repl_id
 from mlflow.spark import FLAVOR_NAME
 
@@ -40,10 +40,8 @@ def _get_current_listener():
 
 def _get_table_info_string(path, version, data_format):
     if data_format == "delta":
-        return "path={path},version={version},format={format}".format(
-            path=path, version=version, format=data_format
-        )
-    return "path={path},format={format}".format(path=path, format=data_format)
+        return f"path={path},version={version},format={data_format}"
+    return f"path={path},format={data_format}"
 
 
 def _merge_tag_lines(existing_tag, new_table_info):
@@ -67,18 +65,22 @@ def _get_spark_major_version(sc):
     return spark_major_version
 
 
-def _get_jvm_event_publisher():
+def _get_jvm_event_publisher(spark_context):
     """
     Get JVM-side object implementing the following methods:
     - init() for initializing JVM state needed for autologging (e.g. attaching a SparkListener
       to watch for datasource reads)
     - register(subscriber) for registering subscribers to receive datasource events
     """
-    jvm = SparkContext._gateway.jvm
+    jvm = spark_context._gateway.jvm
     qualified_classname = "{}.{}".format(_JAVA_PACKAGE, "MlflowAutologEventPublisher")
     return getattr(jvm, qualified_classname)
 
 
+def _generate_datasource_tag_value(table_info_string):
+    return _truncate_and_ellipsize(table_info_string, MAX_TAG_VAL_LENGTH)
+
+
 def _set_run_tag_async(run_id, path, version, data_format):
     _thread_pool.submit(
         _set_run_tag, run_id=run_id, path=path, version=version, data_format=data_format
@@ -91,7 +93,8 @@ def _set_run_tag(run_id, path, version, data_format):
     existing_run = client.get_run(run_id)
     existing_tag = existing_run.data.tags.get(_SPARK_TABLE_INFO_TAG_NAME)
     new_table_info = _merge_tag_lines(existing_tag, table_info_string)
-    client.set_tag(run_id, _SPARK_TABLE_INFO_TAG_NAME, new_table_info)
+    new_tag_value = _generate_datasource_tag_value(new_table_info)
+    client.set_tag(run_id, _SPARK_TABLE_INFO_TAG_NAME, new_tag_value)
 
 
 def _listen_for_spark_activity(spark_context):
@@ -118,7 +121,7 @@ def _listen_for_spark_activity(spark_context):
     callback_server_started = gw.start_callback_server(callback_server_params)
 
     try:
-        event_publisher = _get_jvm_event_publisher()
+        event_publisher = _get_jvm_event_publisher(spark_context)
         event_publisher.init(1)
         _spark_table_info_listener = PythonSubscriber()
         event_publisher.register(_spark_table_info_listener)
@@ -164,7 +167,7 @@ def _get_repl_id():
     return "PythonSubscriber[{filename}][{id}]".format(filename=main_file, id=uuid.uuid4().hex)
 
 
-class PythonSubscriber(object, metaclass=ExceptionSafeClass):
+class PythonSubscriber(metaclass=ExceptionSafeClass):
     """
     Subscriber, intended to be instantiated once per Python process, that logs Spark table
     information propagated from Java to the current MLflow run, starting a run if necessary.
@@ -218,7 +221,7 @@ class PythonSubscriber(object, metaclass=ExceptionSafeClass):
         return self._repl_id
 
     class Java:
-        implements = ["{}.MlflowAutologEventSubscriber".format(_JAVA_PACKAGE)]
+        implements = [f"{_JAVA_PACKAGE}.MlflowAutologEventSubscriber"]
 
 
 class SparkAutologgingContext(RunContextProvider):
@@ -244,8 +247,8 @@ class SparkAutologgingContext(RunContextProvider):
                     seen.add(info)
             if len(unique_infos) > 0:
                 tags = {
-                    _SPARK_TABLE_INFO_TAG_NAME: "\n".join(
-                        [_get_table_info_string(*info) for info in unique_infos]
+                    _SPARK_TABLE_INFO_TAG_NAME: _generate_datasource_tag_value(
+                        "\n".join([_get_table_info_string(*info) for info in unique_infos])
                     )
                 }
             else:
