@@ -13,6 +13,7 @@ import mlflow
 from mlflow.artifacts import download_artifacts
 from mlflow.exceptions import MlflowException
 from mlflow.tracking._model_registry import DEFAULT_AWAIT_MAX_SLEEP_SECONDS
+from mlflow.utils.annotations import experimental
 from mlflow.utils.file_utils import TempDir
 from mlflow.utils.databricks_utils import get_databricks_runtime
 
@@ -68,6 +69,9 @@ class ModelInfo:
     def artifact_path(self):
         """
         Run relative path identifying the logged model.
+
+        :getter: Retrieves the relative path of the logged model.
+        :type: str
         """
         return self._artifact_path
 
@@ -75,23 +79,29 @@ class ModelInfo:
     def flavors(self):
         """
         A dictionary mapping the flavor name to how to serve
-        the model as that flavor. For example:
+        the model as that flavor.
 
-            .. code-block:: python
+        :getter: Gets the mapping for the logged model's flavor that defines parameters used in
+            serving of the model
+        :type: Dict[str, str]
+
+        .. code-block:: python
+            :caption: Example flavor mapping for a scikit-learn logged model
+
+            {
+                "python_function": {
+                    "model_path": "model.pkl",
+                    "loader_module": "mlflow.sklearn",
+                    "python_version": "3.8.10",
+                    "env": "conda.yaml",
+                },
+                "sklearn": {
+                    "pickled_model": "model.pkl",
+                    "sklearn_version": "0.24.1",
+                    "serialization_format": "cloudpickle",
+                },
+            }
 
-                {
-                    "python_function": {
-                        "model_path": "model.pkl",
-                        "loader_module": "mlflow.sklearn",
-                        "python_version": "3.8.10",
-                        "env": "conda.yaml",
-                    },
-                    "sklearn": {
-                        "pickled_model": "model.pkl",
-                        "sklearn_version": "0.24.1",
-                        "serialization_format": "cloudpickle",
-                    },
-                }
         """
         return self._flavors
 
@@ -99,6 +109,10 @@ class ModelInfo:
     def model_uri(self):
         """
         The ``model_uri`` of the logged model in the format ``'runs:/<run_id>/<artifact_path>'``.
+
+        :getter: Gets the uri path of the logged model from the uri `runs:/<run_id>` path
+            encapsulation
+        :type: str
         """
         return self._model_uri
 
@@ -107,6 +121,9 @@ class ModelInfo:
         """
         The ``model_uuid`` of the logged model,
         e.g., ``'39ca11813cfc46b09ab83972740b80ca'``.
+
+        :getter: [Legacy] Gets the model_uuid (run_id) of a logged model
+        :type: str
         """
         return self._model_uuid
 
@@ -115,6 +132,9 @@ class ModelInfo:
         """
         The ``run_id`` associated with the logged model,
         e.g., ``'8ede7df408dd42ed9fc39019ef7df309'``
+
+        :getter: Gets the run_id identifier for the logged model
+        :type: str
         """
         return self._run_id
 
@@ -123,6 +143,9 @@ class ModelInfo:
         """
         A dictionary that contains the metadata of the saved input example, e.g.,
         ``{"artifact_path": "input_example.json", "type": "dataframe", "pandas_orient": "split"}``.
+
+        :getter: Gets the input example if specified during model logging
+        :type: Optional[Dict[str, str]]
         """
         return self._saved_input_example_info
 
@@ -131,6 +154,9 @@ class ModelInfo:
         """
         A dictionary that describes the model input and output generated by
         :py:meth:`ModelSignature.to_dict() <mlflow.models.ModelSignature.to_dict>`.
+
+        :getter: Gets the model signature as a dictionary
+        :type: Optional[Dict[str, Any]]
         """
         warnings.warn(
             "Field signature_dict is deprecated since v1.28.1. Use signature instead.",
@@ -144,6 +170,9 @@ class ModelInfo:
         """
         A :py:class:`ModelSignature <mlflow.models.ModelSignature>` that describes the
         model input and output.
+
+        :getter: Gets the model signature if it is defined
+        :type: Optional[ModelSignature]
         """
         return self._signature
 
@@ -151,6 +180,9 @@ class ModelInfo:
     def utc_time_created(self):
         """
         The UTC time that the logged model is created, e.g., ``'2022-01-12 05:17:31.634689'``.
+
+        :getter: Gets the UTC formatted timestamp for when the model was logged
+        :type: str
         """
         return self._utc_time_created
 
@@ -158,19 +190,23 @@ class ModelInfo:
     def mlflow_version(self):
         """
         Version of MLflow used to log the model
+
+        :getter: Gets the version of Mlflow that was installed when a model was logged
+        :type: str
         """
         return self._mlflow_version
 
+    @experimental
     @property
     def metadata(self) -> Optional[Dict[str, Any]]:
         """
-        .. Note::
-            Experimental: This method may change or be removed in a future release without warning.
-
         User defined metadata added to the model.
 
+        :getter: Gets the user-defined metadata about a model
+        :type: Optional[Dict[str, Any]]
+
         .. code-block:: python
-            :caption: Example
+            :caption: Example usage of Model Metadata
 
             # Create and log a model with metadata to the Model Registry
 
@@ -182,9 +218,12 @@ class ModelInfo:
                 iris = datasets.load_iris()
                 clf = RandomForestClassifier()
                 clf.fit(iris.data, iris.target)
-                mlflow.sklearn.log_model(clf, "iris_rf",
-                                         registered_model_name="model-with-metadata",
-                                         metadata={"metadata_key": "metadata_value"})
+                mlflow.sklearn.log_model(
+                    clf,
+                    "iris_rf",
+                    registered_model_name="model-with-metadata",
+                    metadata={"metadata_key": "metadata_value"},
+                )
 
             # model uri for the above model
             model_uri = "models:/model-with-metadata/1"
@@ -239,9 +278,15 @@ class Model:
         return self.__dict__ == other.__dict__
 
     def get_input_schema(self):
+        """
+        Retrieves the input schema of the Model iff the model was saved with a schema definition.
+        """
         return self.signature.inputs if self.signature is not None else None
 
     def get_output_schema(self):
+        """
+        Retrieves the output schema of the Model iff the model was saved with a schema definition.
+        """
         return self.signature.outputs if self.signature is not None else None
 
     def load_input_example(self, path: str):
@@ -267,14 +312,18 @@ class Model:
         self.flavors[name] = params
         return self
 
+    @experimental
     @property
     def metadata(self) -> Optional[Dict[str, Any]]:
         """
-        .. Note::
-            Experimental: This method may change or be removed in a future release without warning.
-
         Custom metadata dictionary passed to the model and stored in the MLmodel file.
 
+        :getter: Retrieves custom metadata that have been applied to a model instance.
+        :setter: Sets a dictionary of custom keys and values to be included with the model instance
+        :type: Optional[Dict[str, Any]]
+
+        :return: A Dictionary of user-defined metadata iff defined.
+
         .. code-block:: python
             :caption: Example
 
@@ -288,9 +337,12 @@ class Model:
                 iris = datasets.load_iris()
                 clf = RandomForestClassifier()
                 clf.fit(iris.data, iris.target)
-                mlflow.sklearn.log_model(clf, "iris_rf",
-                                         registered_model_name="model-with-metadata",
-                                         metadata={"metadata_key": "metadata_value"})
+                mlflow.sklearn.log_model(
+                    clf,
+                    "iris_rf",
+                    registered_model_name="model-with-metadata",
+                    metadata={"metadata_key": "metadata_value"},
+                )
 
             # model uri for the above model
             model_uri = "models:/model-with-metadata/1"
@@ -298,9 +350,11 @@ class Model:
             # Load the model and access the custom metadata
             model = mlflow.pyfunc.load_model(model_uri=model_uri)
             assert model.metadata.metadata["metadata_key"] == "metadata_value"
+
         """
         return self._metadata
 
+    @experimental
     @metadata.setter
     def metadata(self, value: Optional[Dict[str, Any]]):
         # pylint: disable=attribute-defined-outside-init
@@ -308,6 +362,16 @@ class Model:
 
     @property
     def signature(self):  # -> Optional[ModelSignature]
+        """
+        An optional definition of the expected inputs to and outputs from a model object, defined
+        with both field names and data types. Signatures support both column-based and tensor-based
+        inputs and outputs.
+
+        :getter: Retrieves the signature of a model instance iff the model was saved with a
+            signature definition.
+        :setter: Sets a signature to a model instance.
+        :type: Optional[ModelSignature]
+        """
         return self._signature
 
     @signature.setter
@@ -455,6 +519,7 @@ class Model:
                           .. code-block:: python
 
                             from mlflow.models.signature import infer_signature
+
                             train = df.drop_column("target_label")
                             signature = infer_signature(train, model.predict(train))
 
