@@ -84,6 +84,7 @@ from mlflow.utils.proto_json_utils import message_to_json, parse_dict
 from mlflow.utils.validation import _validate_batch_log_api_req
 from mlflow.utils.string_utils import is_string_type
 from mlflow.utils.uri import is_local_uri
+from mlflow.utils.file_utils import local_file_uri_to_path
 from mlflow.tracking.registry import UnsupportedModelRegistryStoreURIException
 
 _logger = logging.getLogger(__name__)
@@ -1363,6 +1364,26 @@ def _delete_registered_model_tag():
     return _wrap_response(DeleteRegisteredModelTag.Response())
 
 
+def _validate_source(source: str, run_id: str) -> None:
+    if not is_local_uri(source):
+        return
+
+    if run_id:
+        store = _get_tracking_store()
+        run = store.get_run(run_id)
+        source = pathlib.Path(local_file_uri_to_path(source)).resolve()
+        run_artifact_dir = pathlib.Path(local_file_uri_to_path(run.info.artifact_uri)).resolve()
+        if run_artifact_dir in [source, *source.parents]:
+            return
+
+    raise MlflowException(
+        f"Invalid source: '{source}'. To use a local path as source, the run_id request parameter "
+        "has to be specified and the local path has to be contained within the artifact directory "
+        "of the run specified by the run_id.",
+        INVALID_PARAMETER_VALUE,
+    )
+
+
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _create_model_version():
@@ -1378,11 +1399,7 @@ def _create_model_version():
         },
     )
 
-    if is_local_uri(request_message.source):
-        raise MlflowException(
-            f"Model version source cannot be a local path: '{request_message.source}'",
-            INVALID_PARAMETER_VALUE,
-        )
+    _validate_source(request_message.source, request_message.run_id)
 
     model_version = _get_model_registry_store().create_model_version(
         name=request_message.name,
