@@ -3,8 +3,10 @@ from abc import abstractmethod, ABCMeta
 from mlflow.entities import ViewType
 from mlflow.store.entities.paged_list import PagedList
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
+from mlflow.utils.annotations import developer_stable
 
 
+@developer_stable
 class AbstractStore:
     """
     Abstract class for Backend Storage.
@@ -20,22 +22,6 @@ class AbstractStore:
         """
         pass
 
-    @abstractmethod
-    def list_experiments(self, view_type=ViewType.ACTIVE_ONLY, max_results=None, page_token=None):
-        """
-        :param view_type: Qualify requested type of experiments.
-        :param max_results: If passed, specifies the maximum number of experiments desired. If not
-                            passed, all experiments will be returned. However, certain server
-                            backend may apply its own limit. Check returned ``PagedList`` token to
-                            see if additional experiments are available.
-        :param page_token: Token specifying the next page of results. It should be obtained from
-                            a ``list_experiments`` call.
-        :return: A :py:class:`PagedList <mlflow.store.entities.PagedList>` of
-                 :py:class:`Experiment <mlflow.entities.Experiment>` objects. The pagination token
-                 for the next page can be obtained via the ``token`` attribute of the object.
-        """
-        pass
-
     @abstractmethod
     def search_experiments(
         self,
@@ -130,17 +116,12 @@ class AbstractStore:
     def get_experiment_by_name(self, experiment_name):
         """
         Fetch the experiment by name from the backend store.
-        This is a base implementation using ``list_experiments``, derived classes may have
-        some specialized implementations.
 
         :param experiment_name: Name of experiment
 
         :return: A single :py:class:`mlflow.entities.Experiment` object if it exists.
         """
-        for experiment in self.list_experiments(ViewType.ALL):
-            if experiment.name == experiment_name:
-                return experiment
-        return None
+        pass
 
     @abstractmethod
     def delete_experiment(self, experiment_id):
@@ -265,15 +246,25 @@ class AbstractStore:
         self.log_batch(run_id, metrics=[], params=[], tags=[tag])
 
     @abstractmethod
-    def get_metric_history(self, run_id, metric_key):
+    def get_metric_history(self, run_id, metric_key, max_results=None, page_token=None):
         """
-        Return a list of metric objects corresponding to all values logged for a given metric.
+        Return a list of metric objects corresponding to all values logged for a given metric
+        within a run.
 
         :param run_id: Unique identifier for run
         :param metric_key: Metric name within the run
+        :param max_results: Maximum number of metric history events (steps) to return per paged
+            query.
+        :param page_token: A Token specifying the next paginated set of results of metric history.
+            This value is obtained as a return value from a paginated call to GetMetricHistory.
 
         :return: A list of :py:class:`mlflow.entities.Metric` entities if logged, else empty list
         """
+
+        # NB: Pagination for this API is not supported in FileStore or SQLAlchemyStore. The
+        # argument `max_results` is used as a pagination activation flag. If the `max_results`
+        # argument is not provided, this API will return a full metric history event collection
+        # without the paged queries to the backend store.
         pass
 
     def search_runs(
@@ -326,36 +317,6 @@ class AbstractStore:
         """
         pass
 
-    def list_run_infos(
-        self,
-        experiment_id,
-        run_view_type,
-        max_results=SEARCH_MAX_RESULTS_DEFAULT,
-        order_by=None,
-        page_token=None,
-    ):
-        """
-        Return run information for runs which belong to the experiment_id.
-
-        :param experiment_id: The experiment id which to search
-        :param run_view_type: ACTIVE_ONLY, DELETED_ONLY, or ALL runs
-        :param max_results: Maximum number of results desired.
-        :param order_by: List of order_by clauses.
-        :param page_token: Token specifying the next page of results. It should be obtained from
-            a ``list_run_infos`` call.
-
-        :return: A :py:class:`PagedList <mlflow.store.entities.PagedList>` of
-            :py:class:`RunInfo <mlflow.entities.RunInfo>` objects that satisfy the search
-            expressions. If the underlying tracking store supports pagination, the token for the
-            next page may be obtained via the ``token`` attribute of the returned object; however,
-            some store implementations may not support pagination and thus the returned token would
-            not be meaningful in such cases.
-        """
-        search_result = self.search_runs(
-            [experiment_id], None, run_view_type, max_results, order_by, page_token
-        )
-        return PagedList([run.info for run in search_result], search_result.token)
-
     @abstractmethod
     def log_batch(self, run_id, metrics, params, tags):
         """
