@@ -6,6 +6,8 @@ from mlflow.exceptions import MlflowException
 from mlflow.models import Model
 from mlflow.models.model import MLMODEL_FILE_NAME
 from mlflow.protos.databricks_pb2 import RESOURCE_DOES_NOT_EXIST, RESOURCE_ALREADY_EXISTS
+from mlflow.store.artifact.runs_artifact_repo import RunsArtifactRepository
+from mlflow.store.artifact.models_artifact_repo import ModelsArtifactRepository
 from mlflow.tracking.artifact_utils import _download_artifact_from_uri
 from mlflow.utils.uri import append_to_uri_path
 from mlflow.utils.file_utils import _copy_file_or_tree
@@ -41,7 +43,7 @@ def _get_flavor_configuration(model_path, flavor_name):
     return conf
 
 
-def _get_flavor_configuration_from_uri(model_uri, flavor_name):
+def _get_flavor_configuration_from_uri(model_uri, flavor_name, logger):
     """
     Obtains the configuration for the specified flavor from the specified
     MLflow model uri. If the model does not contain the specified flavor,
@@ -50,17 +52,26 @@ def _get_flavor_configuration_from_uri(model_uri, flavor_name):
     :param model_uri: The path to the root directory of the MLflow model for which to load
                        the specified flavor configuration.
     :param flavor_name: The name of the flavor configuration to load.
+    :param logger: The local flavor's logger to report the resolved path of the model uri.
     :return: The flavor configuration as a dictionary.
     """
     try:
+        resolved_uri = model_uri
+        if RunsArtifactRepository.is_runs_uri(model_uri):
+            resolved_uri = RunsArtifactRepository.get_underlying_uri(model_uri)
+            logger.info("'%s' resolved as '%s'", model_uri, resolved_uri)
+        elif ModelsArtifactRepository.is_models_uri(model_uri):
+            resolved_uri = ModelsArtifactRepository.get_underlying_uri(model_uri)
+            logger.info("'%s' resolved as '%s'", model_uri, resolved_uri)
+
         ml_model_file = _download_artifact_from_uri(
-            artifact_uri=append_to_uri_path(model_uri, MLMODEL_FILE_NAME)
+            artifact_uri=append_to_uri_path(resolved_uri, MLMODEL_FILE_NAME)
         )
     except Exception as ex:
         raise MlflowException(
-            f'Failed to download an "{MLMODEL_FILE_NAME}" model file from "{model_uri}": {ex}',
+            f'Failed to download an "{MLMODEL_FILE_NAME}" model file from "{model_uri}"',
             RESOURCE_DOES_NOT_EXIST,
-        )
+        ) from ex
     return _get_flavor_configuration_from_ml_model_file(ml_model_file, flavor_name)
 
 
