@@ -6,13 +6,14 @@ teardown({
 
 test_that("mlflow_create/get_experiment() basic functionality (fluent)", {
   mlflow_clear_test_dir("mlruns")
-
-  experiment_1_id <- mlflow_create_experiment("exp_name", "art_loc")
+  artifact_relative_path <- "art_loc"
+  experiment_1_id <- mlflow_create_experiment("exp_name", artifact_relative_path)
   experiment_1a <- mlflow_get_experiment(experiment_id = experiment_1_id)
   experiment_1b <- mlflow_get_experiment(name = "exp_name")
 
   expect_identical(experiment_1a, experiment_1b)
-  expect_identical(experiment_1a$artifact_location, "art_loc")
+  expected_artifact_location <- sprintf("%s/%s", getwd(), artifact_relative_path)
+  expect_identical(experiment_1a$artifact_location, expected_artifact_location)
   expect_identical(experiment_1a$name, "exp_name")
 })
 
@@ -20,18 +21,19 @@ test_that("mlflow_create/get_experiment() basic functionality (client)", {
   mlflow_clear_test_dir("mlruns")
 
   client <- mlflow_client()
-
+  artifact_relative_path <- "art_loc"
   experiment_1_id <- mlflow_create_experiment(
     client = client,
     name = "exp_name",
-    artifact_location = "art_loc",
+    artifact_location = artifact_relative_path,
     tags = list(foo = "bar", foz = "baz", fiz = "biz")
   )
   experiment_1a <- mlflow_get_experiment(client = client, experiment_id = experiment_1_id)
   experiment_1b <- mlflow_get_experiment(client = client, name = "exp_name")
 
   expect_identical(experiment_1a, experiment_1b)
-  expect_identical(experiment_1a$artifact_location, "art_loc")
+  expected_artifact_location <- sprintf("%s/%s", getwd(), artifact_relative_path)
+  expect_identical(experiment_1a$artifact_location, expected_artifact_location)
   expect_identical(experiment_1a$name, "exp_name")
 
   expect_true(
@@ -70,9 +72,9 @@ test_that("mlflow_search_experiments() works properly", {
   expect_setequal(allexperiments$name, c("Default", "foo1", "foo2", "foo3"))
   default_artifact_loc <- file.path(getwd(), "mlruns", "0", fsep = "/")
   expect_setequal(allexperiments$artifact_location, c(default_artifact_loc,
-                                                      "art_loc1",
-                                                      "art_loc2",
-                                                      "art_loc3"))
+                                                      sprintf("%s/%s", getwd(), "art_loc1"),
+                                                      sprintf("%s/%s", getwd(), "art_loc2"),
+                                                      sprintf("%s/%s", getwd(), "art_loc3")))
   expect_null(allexperiments_result$next_page_token)
 
   ex1_result = mlflow_search_experiments(filter = "attribute.name = 'foo1'")
@@ -113,9 +115,12 @@ test_that("mlflow_search_experiments() works properly", {
 test_that("mlflow_search_experiments() works properly", {
   mlflow_clear_test_dir("mlruns")
   client <- mlflow_client()
-  ex1 <- mlflow_create_experiment(client = client, "foo1", "art_loc1")
-  ex2 <- mlflow_create_experiment(client = client, "foo2", "art_loc2")
-  ex3 <- mlflow_create_experiment(client = client, "foo3", "art_loc3")
+  art_loc_1 <- "art_loc1"
+  art_loc_2 <- "art_loc2"
+  art_loc_3 <- "art_loc3"
+  ex1 <- mlflow_create_experiment(client = client, "foo1", art_loc_1)
+  ex2 <- mlflow_create_experiment(client = client, "foo2", art_loc_2)
+  ex3 <- mlflow_create_experiment(client = client, "foo3", art_loc_3)
 
   mlflow_set_experiment_tag("expgroup", "group1", experiment_id = ex1)
   mlflow_set_experiment_tag("expgroup", "group1", experiment_id = ex3)
@@ -126,9 +131,9 @@ test_that("mlflow_search_experiments() works properly", {
   expect_setequal(allexperiments$name, c("Default", "foo1", "foo2", "foo3"))
   default_artifact_loc <- file.path(getwd(), "mlruns", "0", fsep = "/")
   expect_setequal(allexperiments$artifact_location, c(default_artifact_loc,
-                                                      "art_loc1",
-                                                      "art_loc2",
-                                                      "art_loc3"))
+                                                      sprintf("%s/%s", getwd(), art_loc_1),
+                                                      sprintf("%s/%s", getwd(), art_loc_2),
+                                                      sprintf("%s/%s", getwd(), art_loc_3)))
   expect_null(allexperiments_result$next_page_token)
 
   ex1_result = mlflow_search_experiments(filter = "attribute.name = 'foo1'")
@@ -215,11 +220,12 @@ test_that("mlflow_get_experiment_by_name() works properly", {
     mlflow_get_experiment(client = client, name = "exp"),
     "Could not find experiment with name 'exp'"
   )
-  experiment_id <- mlflow_create_experiment(client = client, "exp", "art")
+  artifact_relative_path <- "art"
+  experiment_id <- mlflow_create_experiment(client = client, "exp", artifact_relative_path)
   experiment <- mlflow_get_experiment(client = client, name = "exp")
   expect_identical(experiment_id, experiment$experiment_id)
   expect_identical(experiment$name, "exp")
-  expect_identical(experiment$artifact_location, "art")
+  expect_identical(experiment$artifact_location, sprintf("%s/%s", getwd(), artifact_relative_path))
 })
 
 test_that("infer experiment id works properly", {
@@ -249,9 +255,10 @@ test_that("experiment setting works", {
 
 test_that("mlflow_set_experiment() creates experiments", {
   mlflow_clear_test_dir("mlruns")
-  mlflow_set_experiment(experiment_name = "foo", artifact_location = "artifact/location")
+  artifact_relative_path <- "artifact/location"
+  mlflow_set_experiment(experiment_name = "foo", artifact_location = artifact_relative_path)
   experiment <- mlflow_get_experiment()
-  expect_identical(experiment$artifact_location, "artifact/location")
+  expected_artifact_location <- sprintf("%s/%s", getwd(), artifact_relative_path)
+  expect_identical(experiment$artifact_location, expected_artifact_location)
   expect_identical(experiment$name, "foo")
 })
-
